@@ -47,11 +47,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "5-Aug-24"
+#define SND_DATE "10-Sep-24"
 #ifndef SND_VERSION
-#define SND_VERSION "24.6"
+#define SND_VERSION "24.7"
 #endif
 #define SND_MAJOR_VERSION "24"
-#define SND_MINOR_VERSION "6"
+#define SND_MINOR_VERSION "7"
 
 #endif
